@@ -4,12 +4,12 @@
 #::::::::::::::::
 
 subroutine  llrmnewton (cd, nxis, q, nxi, rs, nobs, cntsum, cnt, qdrs, nqd, nx, xxwt,
-                        prec, maxiter, mchpr, wk, info)
+                        prec, maxiter, mchpr, jpvt, wk, info)
 
-integer  nxis, nxi, nobs, cntsum, cnt(*), nqd, nx, maxiter, info
+integer  nxis, nxi, nobs, cntsum, cnt(*), nqd, nx, maxiter, jpvt(*), info
 double precision  cd(*), q(nxi,*), rs(nxis,*), qdrs(nqd,nxis,*), xxwt(*), prec, mchpr, wk(*)
 
-integer  iwt, iwtsum, imrs, ifit, imu, imuwk, iv, ivwk, ijpvt, icdnew, iwtnew, iwtnewsum,
+integer  iwt, iwtsum, imrs, ifit, imu, imuwk, iv, ivwk, icdnew, iwtnew, iwtnewsum,
          ifitnew, iwk
 
 iwt = 1
@@ -20,8 +20,7 @@ imu = ifit + nobs
 imuwk = imu + nxis
 iv = imuwk + nxis
 ivwk = iv + nxis*nxis
-ijpvt = ivwk + nxis*nxis
-icdnew = ijpvt + nxis
+icdnew = ivwk + nxis*nxis
 iwtnew = icdnew + nxis
 iwtnewsum = iwtnew + nqd*nx
 ifitnew = iwtnewsum + nx
@@ -29,7 +28,7 @@ iwk = ifitnew + nobs
 
 call  llrmnewton1 (cd, nxis, q, nxi, rs, nobs, cntsum, cnt, qdrs, nqd, nx, xxwt,
                    prec, maxiter, mchpr, wk(iwt), wk(iwtsum), wk(imrs), wk(ifit),
-                   wk(imu), wk(imuwk), wk(iv), wk(ivwk), wk(ijpvt), wk(icdnew),
+                   wk(imu), wk(imuwk), wk(iv), wk(ivwk), jpvt, wk(icdnew),
                    wk(iwtnew), wk(iwtnewsum), wk(ifitnew), wk(iwk), info)
 
 return
